# free

[![PyPI](https://img.shields.io/pypi/l/free.svg)](https://pypi.python.org/pypi/macos-free)
[![PyPI](https://img.shields.io/pypi/v/free.svg)](https://pypi.python.org/pypi/macos-free)
[![PyPI](https://img.shields.io/pypi/pyversions/free.svg)](https://pypi.python.org/pypi/macos-free)
[![Travis](https://img.shields.io/travis/rust-lang/rust.svg)]()

Memory usage for macos,  an alternative to free command.

## Installation

You can install "macos-free" via `pip` from `PyPI`:

	$ pip install macos-free
	
## Usage

	Usage: free [OPTIONS]

	Options:
	  -b, --bytes    show output in bytes
	  -k, --kilo     show output in kilobytes
	  -m, --mega     show output in megabytes
	  -g, --giga     show output in gigabytes
	  --tera         show output in terabytes
	  -h, --human    show human-readable output
	  --si           use powers of 1000 not 1024
	  -V, --version  output version information and exit
	  --help         Show this message and exit.

